@@ -423,6 +423,12 @@ c                                         kaon
               p.charge = pj.charge
          else
               p.charge = 0
+              call rndc(u) 
+              if(u .lt. 0.5) then
+                 p.subcode = k0s
+              else
+                 p.subcode = k0l
+              endif
          endif
       elseif(k0 .eq. knuc) then
 c                                        nucleon
@@ -447,6 +453,8 @@ c              same charge
          p.charge = 0
       elseif(k0 .eq. kphi) then
          p.charge = 0
+      elseif(k0 .eq. keta) then
+         p.charge = 0
       else
          write(msg,*) ' code=',k0,' undef. in cfclp'
          call cerrorMsg(msg, 0)
